function OrderByable(config) {
	var self =  this;

	var orderByColumns = [];
	this.getOrderByColumns = function getOrderByColumns() {
		return orderByColumns;
	};

	this.updateOrderByColumns = function() {
		orderByColumns = [];
		addOrderByFromGroups();
		addUserDefinedOrderBy();
	};

	var addUserDefinedOrderBy = function() {
		if (self.widget.order && !Util.isFunction(self.widget.order)) {
			Util.parseToArray(self.widget.order).forEach(function(collum) {
				addColumnToOrder(collum, self.widget.reverse);
			});
		}
	};

	var addOrderByFromGroups = function() {
		if (self.widget.groups && self.widget.orderFromGroups) {
			self.widget.groups.forEach(function(group, index) {
				addColumnToOrder(group.name);
			});
		}
	};

	var addColumnToOrder = function addColumnToOrder(columnName, reverse) {
		var field = self.widget.getField(columnName);
		if (field && field.getTemplateSimpleName) {
			var template = field.getTemplateSimpleName();
			if (orderByFieldFlow[template]) {
				columnName = orderByFieldFlow[template](columnName, field);
			}
		}

		var orderByExpression = (reverse ? '-' : '') + columnName;
		if (!~orderByColumns.indexOf(orderByExpression)) {
			orderByColumns.push(orderByExpression);
		}
	};

	var orderByFieldFlow = {
		"datetime.html": getDatetimeProxyToOrderBy,
		"calendar.html": getDateProxyToOrderBy,
		"select-month.html": getMonthProxyToOrderBy
	};

	function getDateTimeFormat(field) {
		var format;
		var dateFormat = field["datetime-dateFormat"];
		var timeFormat = field["datetime-timeFormat"];
		switch (field['datetime-preset']) {
			case 'date':
			case 'month':
				format = dateFormat;
				break;
			case 'time':
				format = timeFormat;
				break;
			default:
				format = dateFormat + ' ' + timeFormat;
		}
		return format;
	}


	function getDatetimeProxyToOrderBy(columnName, field) {
		var format = getDateTimeFormat(field);
		return getProxyToOrderBy(columnName, format);
	}

	function getDateProxyToOrderBy(columnName, field) {
		var format = getDateTimeFormat(field);
		return getProxyToOrderBy(columnName, field.dateFormat || format);
	}

	function getMonthProxyToOrderBy(columnName, field) {
		var format = getDateTimeFormat(field);
		return getProxyToOrderBy(columnName, field.dateFormat || format);
	}

	function getProxyToOrderBy(columnName, format) {
		var proxyProperty = getProxyProperty(columnName);
		buildDateProxyColumn(proxyProperty, columnName, format);
		return proxyProperty;
	}

	function getProxyProperty(columnName) {
		return "__proxy_" + columnName;
	}

	function buildDateProxyColumn(proxyProperty, sourceColumn, format) {
		if (self.widget.dataSource && Util.isArray(self.widget.dataSource.data)) {
			self.widget.dataSource.data.forEach(function(item){
				var value = item[sourceColumn] || "";
				item[proxyProperty] = moment(value, format).valueOf();
			});
		}
	}

}